#! /usr/bin/perl -w

#  This file is part of ff3d - http://www.freefem.org/ff3d
#  Copyright (C) 2003  Laboratoire J.-L. Lions UPMC Paris

#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2, or (at your option)
#  any later version.

#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

#  $Id: R3functions.pl,v 1.4 2003/08/04 09:26:42 ArceneL Exp $

# Checks predefined and user-defined R3 functions (R^3 -> R).

require 'check.ph';

Run(<< 'EOF');

// Test predefined functions x, y and z
cout << "x(1,2,3) = " << x(1,2,3) << "\n";
cout << "y(1,2,3) = " << y(1,2,3) << "\n";
cout << "z(1,2,3) = " << z(1,2,3) << "\n";

// Test functions definition
function c = 1;
cout << "c(1,0,0) = " << c(1,0,0) << "\n";
cout << "c(0,1,0) = " << c(0,1,0) << "\n";
cout << "c(0,0,1) = " << c(0,0,1) << "\n";

function f = x + y + z;
cout << "f(1,0,0) = " << f(1,0,0) << "\n";
cout << "f(0,2,0) = " << f(0,2,0) << "\n";
cout << "f(0,0,3) = " << f(0,0,3) << "\n";

// Test composed functions
double pi = 3.1515926;
function F = exp(-2*asin(abs(x) + abs(y) + abs(z))/pi)^-1;
cout << "F(1,0,0) = " << F(1,0,0) << "\n";
cout << "F(0.5,-0.5,0) = " << F(0.5,-0.5,0) << "\n";
double OneThird = 1/3;
cout << "F(-OneThird,OneThird,-OneThird) = "
    << F(-OneThird,OneThird,-OneThird) << "\n";

EOF

# Test predefined functions x, y and z
NumCheck('x\(1,2,3\) = ',1);
NumCheck('y\(1,2,3\) = ',2);
NumCheck('z\(1,2,3\) = ',3);

# Test functions definition
NumCheck('c\(1,0,0\) = ',1);
NumCheck('c\(0,1,0\) = ',1);
NumCheck('c\(0,0,1\) = ',1);

NumCheck('f\(1,0,0\) = ',1);
NumCheck('f\(0,2,0\) = ',2);
NumCheck('f\(0,0,3\) = ',3);

# Test composed functions
$e = 2.71828;
NumCheck('F\(1,0,0\) = ',$e,1e-2);
NumCheck('F\(0.5,-0.5,0\) = ',$e,1e-2);
NumCheck('F\(-OneThird,OneThird,-OneThird\) = ',$e,1e-2);

Report();
