#! /usr/bin/perl -w

#  This file is part of ff3d - http://www.freefem.org/ff3d
#  Copyright (C) 2003  Laboratoire J.-L. Lions UPMC Paris

#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2, or (at your option)
#  any later version.

#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

#  $Id: laplacian-lens.pl,v 1.4 2003/11/21 13:00:43 ArceneL Exp $

# A Laplacian on a lens-like geometry. The value of this test is
# that it defines boundary conditions on pieces of objects.

require 'check.ph';
CleanUp('laplacian-lens.bb');

# The Povray scene
WriteFile("laplacian-lens.pov",<< 'EOF');

/* We define two spheres to be able to apply different boundary
conditions on each */

sphere {
	<0,0,0>,1
	pigment {
		color rgb <1,0,0>
	}
}

sphere {
	<1,0,0>,1
	pigment {
		color rgb <0,1,0>
	}
}

EOF

# Runs the FreeFEM3D script
Run(<< 'EOF');
vector n = (16,16,16);
vector a = (-2,-2,-2);
vector b = (3,2,2);

scene S = pov("laplacian-lens.pov");
mesh M = structured(n,a,b);
domain O = domain(S,outside(<1,0,0>) or outside(<0,1,0>));

solve(u) in O by M{

    pde(u)
	-div(grad(u)) = 0;
    u = 1 on <1,0,0>;
    dnu(u) = 0 on <0,1,0>;
    u = 0 on M;
};

save(medit,"laplacian-lens",u,M);

// Also saves mesh, just for debugging purposes
save(medit,"laplacian-lens",M);
EOF

# Compares the resulting output with a reference
VectorCheck('laplacian-lens.bb','laplacian-lens-ref.bb',1e-6,"laplacian-lens");

Report();
