#! /usr/bin/perl -w

#  This file is part of ff3d - http://www.freefem.org/ff3d
#  Copyright (C) 2003  Laboratoire J.-L. Lions UPMC Paris

#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2, or (at your option)
#  any later version.

#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

#  $Id: laplacian-spike.pl,v 1.4 2003/11/21 13:00:43 ArceneL Exp $

# A Laplacian on a spiky geometry.

require 'check.ph';
CleanUp('laplacian-spike.bb');

# The Povray scene
WriteFile("laplacian-spike.pov",<< 'EOF');
/* The sphere surrounds the box in such a way that only one corner
still appears */

union{
	box {
		<-1,-1,-1>,<1,1,1>
	}
	sphere {
		<-1,-1,-1>,2
	}
	pigment {
		color rgb <1,0,0>
	}
}
EOF

# Runs the FreeFEM3D script
Run(<< 'EOF');
vector n = (20,20,20);
vector a = (-4,-4,-4);
vector b = (2,2,2);

scene S = pov("laplacian-spike.pov");
mesh M = structured(n,a,b);
domain O = domain(S,outside(<1,0,0>));

solve(u) in O by M{

    pde(u)
	-div(grad(u)) = 0;
    u = 1 on <1,0,0>;
    u = 0 on M;
};

save(medit,"laplacian-spike",M);
save(medit,"laplacian-spike",u,M);
EOF

# Compares the resulting output with a reference
VectorCheck('laplacian-spike.bb','laplacian-spike-ref.bb',1e-6,
	    'laplacian-spike');

Report();
