#! /usr/bin/perl -w

#  This file is part of ff3d - http://www.freefem.org/ff3d
#  Copyright (C) 2003  Laboratoire J.-L. Lions UPMC Paris

#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2, or (at your option)
#  any later version.

#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

#  $Id: refined.pl,v 1.2 2003/11/21 10:30:16 ArceneL Exp $

# Test with a finer mesh, at least in one direction.

require 'check.ph';
CleanUp('refined.bb');

# The Povray scene: a basic box, made of 6 planes.
WriteFile("test-refined.pov",<< 'EOF');
intersection{
    plane{<1,0,0>,1.0}
    plane{<-1,0,0>,1.0}
    plane{<0,1,0>,1.0}
    plane{<0,-1,0>,1.0}
    plane{<0,0,1>,1.0}
    plane{<0,0,-1>,1.0}
    pigment{color rgb <1,0,0>}
}
EOF

# Runs the FreeFEM3D script
Run(<< 'EOF');
vector n = (13,13,130);
vertex a = (-2,-2,-2);
vertex b = (2,2,2);
mesh M = structured(n,a,b);
scene S = pov("test-refined.pov");
domain O = domain(S,outside(<1,0,0>));

solve(u) in O by M{

    pde(u)
	-div(grad(u)) = 1;
    u = 0 on <1,0,0>;
    u = 0 on M;
};

// Prints the value of one particular point, at the center of the
// domain. If the cube is correctly defined, this point should have a
// precise value.

cout << "u(0,0,0)=" << u(0,0,0) << "\n";

// Also saves the mesh, just for debugging purposes.
save(medit,"refined",u,M);
save(medit,"refined",M);
EOF

# Compares the resulting output with a reference
VectorCheck('refined.bb','refined-ref.bb',1e-6);

Report();
